#!/bin/sh
#
# build.sh
#

DIR=lib
if [ -d $DIR ]; then
	cd $DIR
	make
	cp lib.a ../copy/usr/lib/libc.a -f
	cp crt0/crt0.o ../copy/usr/lib/gcc-lib/i386-elf/3.0.4/crtbegin.o -f
	cd ../
fi

DIR=sbin
if [ -d $DIR ]; then
	cd $DIR
	make
	cd ../
fi

DIR=command
if [ -d $DIR ]; then
	cd $DIR
	make
	cd ../
fi

DIR=module/console.mod
if [ -d $DIR ]; then
	cd $DIR
	make
	cd ../../
fi

DIR=module/ata.mod
if [ -d $DIR ]; then
	cd $DIR
	make
	cd ../../
fi

DIR=module/test
if [ -d $DIR ]; then
	cd $DIR
	make
	cd ../../
fi

DIR=test
if [ -d $DIR ]; then
	cd $DIR
	make
	cd ../
fi

if [ -d copy ]; then
	cp include/* copy/usr/include/ -r
	cp ../sys copy/usr/include/ -r
	cp ../netinet copy/usr/include/ -r
	cp ../netinet6 copy/usr/include/ -r
	mkdir copy/usr/include/i386
	cp ../i386/*h copy/usr/include/i386/ -r
fi
